@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -30,6 +30,8 @@
 
 #include "configure.hpp"
 
+#include "cli/extract.hpp"
+
 #ifdef DEBUG
 
 namespace loader { struct offsets; }
@@ -38,6 +40,8 @@ namespace setup { struct info; }
 void print_offsets(const loader::offsets & offsets);
 void print_info(const setup::info & info);
 
+void dump_headers(std::istream & is, const loader::offsets & offsets, const extract_options & o);
+
 #endif // DEBUG
 
 #endif // INNOEXTRACT_CLI_DEBUG_HPP
