@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -493,10 +493,10 @@ void header::load(std::istream & is, const version & version) {
 		uninstall_display_size = 0;
 	}
 	
-	if(version == INNO_VERSION_EXT(5, 5, 0, 1)) {
+	if(version == INNO_VERSION_EXT(5, 4,  2, 1) || version == INNO_VERSION_EXT(5, 5, 0, 1)) {
 		/*
 		 * This is needed to extract an Inno Setup variant (BlackBox v2?) that uses
-		 * the 5.5.0 (unicode) data version string while the format differs:
+		 * the 5.4.2 or 5.5.0 (unicode) data version string while the format differs:
 		 * The language entries are off by one byte and the EncryptionUsed flag
 		 * gets set while there is no decrypt_dll.
 		 * I'm not sure where exactly this byte goes, but it's after the compression
@@ -715,24 +715,24 @@ void header::decode(util::codepage_id codepage) {
 	util::to_utf8(app_support_url, codepage);
 	util::to_utf8(app_updates_url, codepage);
 	util::to_utf8(app_version, codepage);
-	util::to_utf8(default_dir_name, codepage);
+	util::to_utf8(default_dir_name, codepage, &lead_bytes);
 	util::to_utf8(default_group_name, codepage);
-	util::to_utf8(base_filename, codepage);
-	util::to_utf8(uninstall_files_dir, codepage);
-	util::to_utf8(uninstall_name, codepage);
-	util::to_utf8(uninstall_icon, codepage);
-	util::to_utf8(app_mutex, codepage);
+	util::to_utf8(base_filename, codepage, &lead_bytes);
+	util::to_utf8(uninstall_files_dir, codepage, &lead_bytes);
+	util::to_utf8(uninstall_name, codepage, &lead_bytes);
+	util::to_utf8(uninstall_icon, codepage, &lead_bytes);
+	util::to_utf8(app_mutex, codepage, &lead_bytes);
 	util::to_utf8(default_user_name, codepage);
 	util::to_utf8(default_user_organisation, codepage);
 	util::to_utf8(default_serial, codepage);
-	util::to_utf8(app_readme_file, codepage);
+	util::to_utf8(app_readme_file, codepage, &lead_bytes);
 	util::to_utf8(app_contact, codepage);
 	util::to_utf8(app_comments, codepage);
-	util::to_utf8(app_modify_path, codepage);
-	util::to_utf8(create_uninstall_registry_key, codepage);
+	util::to_utf8(app_modify_path, codepage, &lead_bytes);
+	util::to_utf8(create_uninstall_registry_key, codepage, &lead_bytes);
 	util::to_utf8(uninstallable, codepage);
 	util::to_utf8(close_applications_filter, codepage);
-	util::to_utf8(setup_mutex, codepage);
+	util::to_utf8(setup_mutex, codepage, &lead_bytes);
 	util::to_utf8(changes_environment, codepage);
 	util::to_utf8(changes_associations, codepage);
 	
