@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -48,6 +48,7 @@ struct icon_entry : public item {
 		FolderShortcut,
 		ExcludeFromShowInNewInstall,
 		PreventPinning,
+		HasAppUserModelToastActivatorCLSID,
 		// obsolete options:
 		RunMinimized
 	);
@@ -65,6 +66,7 @@ struct icon_entry : public item {
 	std::string icon_file;
 	std::string comment;
 	std::string app_user_model_id;
+	std::string app_user_model_toast_activator_clsid;
 	
 	int icon_index;
 	
