@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -47,13 +47,13 @@ void ini_entry::load(std::istream & is, const info & i) {
 		(void)util::load<boost::uint32_t>(is); // uncompressed size of the entry
 	}
 	
-	is >> util::encoded_string(inifile, i.codepage);
+	is >> util::encoded_string(inifile, i.codepage, i.header.lead_bytes);
 	if(inifile.empty()) {
 		inifile = "{windows}/WIN.INI";
 	}
-	is >> util::encoded_string(section, i.codepage);
+	is >> util::encoded_string(section, i.codepage, i.header.lead_bytes);
 	is >> util::encoded_string(key, i.codepage);
-	is >> util::encoded_string(value, i.codepage);
+	is >> util::encoded_string(value, i.codepage, i.header.lead_bytes);
 	
 	load_condition_data(is, i);
 	
