@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Daniel Scharrer
+ * Copyright (C) 2011-2019 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -31,7 +31,7 @@
 
 namespace setup {
 
-struct version;
+struct info;
 
 struct permission_entry {
 	
@@ -39,7 +39,7 @@ struct permission_entry {
 	
 	std::string permissions;
 	
-	void load(std::istream & is, const version & version);
+	void load(std::istream & is, const info & i);
 	
 };
 
