@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -65,7 +65,7 @@ void registry_entry::load(std::istream & is, const info & i) {
 		(void)util::load<boost::uint32_t>(is); // uncompressed size of the entry
 	}
 	
-	is >> util::encoded_string(key, i.codepage);
+	is >> util::encoded_string(key, i.codepage, i.header.lead_bytes);
 	if(i.version.bits() != 16) {
 		is >> util::encoded_string(name, i.codepage);
 	} else {
