@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -160,11 +160,13 @@ const known_version versions[] = {
 	{ "Inno Setup Setup Data (5.3.10)",                     INNO_VERSION_EXT(5, 3, 10, 0), 0 },
 	{ "Inno Setup Setup Data (5.3.10) (u)",                 INNO_VERSION_EXT(5, 3, 10, 0), version::Unicode },
 	{ "Inno Setup Setup Data (5.4.2)",                      INNO_VERSION_EXT(5, 4,  2, 0), 0 },
-	{ "Inno Setup Setup Data (5.4.2) (u)",                  INNO_VERSION_EXT(5, 4,  2, 0), version::Unicode },
+	{ "Inno Setup Setup Data (5.4.2) (u)",  /* ambiguous */ INNO_VERSION_EXT(5, 4,  2, 0), version::Unicode },
+	{ "" /* BlackBox v1? */,                                INNO_VERSION_EXT(5, 4,  2, 1), 0 },
+	{ "" /* BlackBox v1? */,                                INNO_VERSION_EXT(5, 4,  2, 1), version::Unicode },
 	{ "Inno Setup Setup Data (5.5.0)",                      INNO_VERSION_EXT(5, 5,  0, 0), 0 },
 	{ "Inno Setup Setup Data (5.5.0) (u)",  /* ambiguous */ INNO_VERSION_EXT(5, 5,  0, 0), version::Unicode },
-	{ "" /* BlackBox v2? */,                                INNO_VERSION_EXT(5, 5,  0, 1), 0 },
-	{ "" /* BlackBox v2? */,                                INNO_VERSION_EXT(5, 5,  0, 1), version::Unicode },
+	{ "" /* BlackBox v2 / Inno Setup Ultra */,              INNO_VERSION_EXT(5, 5,  0, 1), 0 },
+	{ "" /* BlackBox v2 / Inno Setup Ultra */,              INNO_VERSION_EXT(5, 5,  0, 1), version::Unicode },
 	{ "Inno Setup Setup Data (5.5.6)",                      INNO_VERSION_EXT(5, 5,  6, 0), 0 },
 	{ "Inno Setup Setup Data (5.5.6) (u)",                  INNO_VERSION_EXT(5, 5,  6, 0), version::Unicode },
 	{ "Inno Setup Setup Data (5.5.7)",      /* ambiguous */ INNO_VERSION_EXT(5, 5,  7, 0), 0 },
@@ -178,6 +180,7 @@ const known_version versions[] = {
 	{ "Inno Setup Setup Data (5.6.2)",     /* prerelease */ INNO_VERSION_EXT(5, 6,  2, 0), 0 },
 	{ "Inno Setup Setup Data (5.6.2) (u)", /* prerelease */ INNO_VERSION_EXT(5, 6,  2, 0), version::Unicode },
 	{ "Inno Setup Setup Data (6.0.0) (u)",                  INNO_VERSION_EXT(6, 0,  0, 0), version::Unicode },
+	{ "Inno Setup Setup Data (6.1.0) (u)",                  INNO_VERSION_EXT(6, 1,  0, 0), version::Unicode },
 };
 
 } // anonymous namespace
@@ -277,7 +280,7 @@ void version::load(std::istream & is) {
 	char * end = std::find(version_string, version_string + boost::size(version_string), '\0');
 	std::string version_str(version_string, end);
 	debug("unknown version: \"" << version_str << '"');
-	if(version_str.find("Inno Setup") == std::string::npos) {
+	if(!boost::contains(version_str, "Inno Setup")) {
 		throw version_error();
 	}
 	
@@ -372,6 +375,11 @@ bool version::is_ambiguous() const {
 		return true;
 	}
 	
+	if(value == INNO_VERSION(5, 4, 2)) {
+		// might be either 5.4.2 or 5.4.2.1
+		return true;
+	}
+	
 	if(value == INNO_VERSION(5, 5, 0)) {
 		// might be either 5.5.0 or 5.5.0.1
 		return true;
