@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Daniel Scharrer
+ * Copyright (C) 2011-2020 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -468,14 +468,41 @@ void utf16le_to_wtf8(const std::string & from, std::string & to) {
 	
 }
 
-void wtf8_to_utf16le(const std::string & from, std::string & to) {
+const char * wtf8_find_end(const char * begin, const char * end) {
+	
+	const char * i = end;
+	while(i != begin && is_utf8_continuation_byte(boost::uint8_t(*(i - 1)))) {
+		i--;
+	}
+	
+	if(i != begin) {
+		unicode_char chr = boost::uint8_t(*(i - 1));
+		size_t expected = 0;
+		if(chr & (1 << 7)) {
+			expected++;
+			if(chr & (1 << (5 + 6))) {
+				expected++;
+				if(chr & (1 << (4 + 6 + 6))) {
+					expected++;
+				}
+			}
+		}
+		if(expected > size_t(end - i)) {
+			return i - 1;
+		}
+	}
+	
+	return end;
+}
+
+void wtf8_to_utf16le(const char * begin, const char * end, std::string & to) {
 	
 	to.clear();
-	to.reserve(from.size() * 2); // optimistically, most strings only have ASCII characters
+	to.reserve(size_t(end - begin) * 2); // optimistically, most strings only have ASCII characters
 	
-	for(std::string::const_iterator i = from.begin(); i != from.end(); ) {
+	for(const char * i = begin; i != end; ) {
 		
-		unicode_char chr = utf8_read(i, from.end());
+		unicode_char chr = utf8_read(i, end);
 		
 		if(chr >= 0x10000) {
 			chr -= 0x10000;
@@ -491,6 +518,10 @@ void wtf8_to_utf16le(const std::string & from, std::string & to) {
 	
 }
 
+void wtf8_to_utf16le(const std::string & from, std::string & to) {
+	return wtf8_to_utf16le(from.c_str(), from.c_str() + from.size(), to);
+}
+
 namespace {
 
 unicode_char windows1252_replacements[] = {
@@ -752,7 +783,8 @@ bool from_utf8_win32(const std::string & from, std::string & to, codepage_id cod
 
 #endif // INNOEXTRACT_HAVE_WIN32_CONV
 
-void to_utf8(const std::string & from, std::string & to, codepage_id codepage) {
+void to_utf8(const std::string & from, std::string & to, codepage_id codepage,
+             const std::bitset<256> * lead_bytes) {
 	
 	switch(codepage) {
 		case cp_utf16le:     utf16le_to_wtf8(from, to); return;
@@ -761,6 +793,30 @@ void to_utf8(const std::string & from, std::string & to, codepage_id codepage) {
 		default: break;
 	}
 	
+	if(lead_bytes) {
+		std::string buffer;
+		for(size_t start = 0; start < from.length();) {
+			size_t end = start;
+			while(end < from.length()) {
+				if(lead_bytes->test(static_cast<unsigned char>(from[end]))) {
+					end = std::min(from.length(), end + 2);
+				} else if(from[end] != 0x5C) {
+					end++;
+				} else {
+					break;
+				}
+			}
+			buffer = from.substr(start, end - start);
+			util::to_utf8(buffer, codepage, NULL);
+			to.append(buffer);
+			if(end < from.length()) {
+				to.push_back('\\');
+			}
+			start = end + 1;
+		}
+		return;
+	}
+	
 	#if INNOEXTRACT_HAVE_ICONV
 	if(to_utf8_iconv(from, to, codepage)) {
 		return;
@@ -779,7 +835,7 @@ void to_utf8(const std::string & from, std::string & to, codepage_id codepage) {
 
 } // anonymous namespace
 
-void to_utf8(std::string & data, codepage_id codepage) {
+void to_utf8(std::string & data, codepage_id codepage, const std::bitset<256> * lead_bytes) {
 	
 	if(data.empty() || is_utf8(data, codepage)) {
 		// Already UTF-8
@@ -787,7 +843,7 @@ void to_utf8(std::string & data, codepage_id codepage) {
 	}
 	
 	std::string buffer;
-	to_utf8(data, buffer, codepage);
+	to_utf8(data, buffer, codepage, lead_bytes);
 	std::swap(data, buffer);
 }
 
