@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Daniel Scharrer
+ * Copyright (C) 2011-2019 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -83,6 +83,22 @@ public:
 		return reinterpret_cast<TypesafeBoolean>(_flags.any());
 	}
 	
+	bool operator==(flags o) const {
+		return _flags == o._flags;
+	}
+	
+	bool operator!=(flags o) const {
+		return _flags != o._flags;
+	}
+	
+	bool operator==(Zero /* zero */) const {
+		return _flags == 0;
+	}
+	
+	bool operator!=(Zero /* zero */) const {
+		return _flags != 0;
+	}
+	
 	flags operator~() const {
 		return flags(~_flags);
 	}
