@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2015 Daniel Scharrer
+ * Copyright (C) 2011-2019 Daniel Scharrer
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author(s) be held liable for any damages
@@ -51,3 +51,14 @@ logger::~logger() {
 	}
 	
 }
+
+std::streambuf * warning_suppressor::set_streambuf(std::streambuf * streambuf) {
+	return std::cerr.rdbuf(streambuf);
+}
+
+void warning_suppressor::flush() {
+	restore();
+	std::cerr << buffer.str();
+	logger::total_warnings += warnings;
+	logger::total_errors += errors;
+}
